---
title: <span class="badge object-type-scalar"></span> TeraFlopsPerSecond
---
# <span class="badge object-type-scalar"></span> TeraFlopsPerSecond

Computation: TFLOP/s

## Definition

```python
# Computation: TFLOP/s
TeraFlopsPerSecond: typing.Literal["tflops"] = "tflops"
```
